from .utils.serialize import braket_to_sw, sw_to_braket
from braket.circuits import Circuit
from braket.tasks import GateModelQuantumTaskResult
import strangeworks
from strangeworks.jobs.jobs import Job


def get_backends():
    res = []
    backends = strangeworks.client.circuit_runner.get_backends(pprint=False)
    for b in backends:
        if "aws" in b.selector_id():
            res.append(b.selector_id())
    return res


def run_circuit(circuit: Circuit, backend: str, shots: int = 1, **kwargs) -> Job:
    payload = braket_to_sw(circuit)
    job = strangeworks.circuit_runner.run(
        payload=payload, shots=shots, backend=backend, **kwargs
    )
    return job


def get_circuit_results(job: Job) -> GateModelQuantumTaskResult:
    return sw_to_braket(job.results())



import braket._sdk
from braket.circuits import Circuit
from braket.schema_common import BraketSchemaBase
from braket.tasks import GateModelQuantumTaskResult
import json


def braket_to_sw(circuit: Circuit) -> dict:
    if not isinstance(circuit, Circuit):
        raise Exception(
            f"strangeworks-braket does not know how to serialize the type {type(circuit)}"
        )

    return {
        "circuit": circuit.to_ir().json(),
        "circuit_type": "braket.circuits.Circuit",
        "version": braket._sdk.__version__,
    }


def sw_to_braket(result: dict) -> GateModelQuantumTaskResult:
    bsh = BraketSchemaBase.parse_raw_schema(json.dumps(result))
    task_result = GateModelQuantumTaskResult.from_object(bsh)
    return task_result



"""Strangeworks Braket SDK"""
import importlib.metadata

__version__ = importlib.metadata.version("strangeworks-braket")

from strangeworks.braket.utils.serialize import braket_to_sw, sw_to_braket
from strangeworks.braket.swbraket import get_backends, run_circuit, get_circuit_results



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['strangeworks', 'strangeworks.braket', 'strangeworks.braket.utils']

package_data = \
{'': ['*']}

install_requires = \
['amazon-braket-sdk==1.11.1', 'strangeworks>=0.2.0,<0.3.0']

setup_kwargs = {
    'name': 'strangeworks-braket',
    'version': '0.1.1',
    'description': 'Strangeworks Braket SDK extension',
    'long_description': '| ⚠️    | This SDK is currently in pre-release alpha state and subject to change. To get more info or access to test features check out the [Strangeworks Backstage Pass Program](https://strangeworks.com/backstage). |\n|---------------|:------------------------|\n# Strangeworks Braket Extension\n\n Strangeworks Python SDK extension for Braket.\n\n\n \n For more information on using the SDK check out the [Strangeworks documentation](https://docs.strangeworks.com/).\n',
    'author': 'Strange Devs',
    'author_email': 'hello@strangeworks.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': None,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.8,<4.0',
}


setup(**setup_kwargs)
